==> ejc-lz-impl-3.0.0-20220509.024412-92-sources.jar: com/ejianc/business/base/controller/SupplierinfoController.java <==
package com.ejianc.business.base.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.base.bean.*;
import com.ejianc.business.base.service.ISupplierbankService;
import com.ejianc.business.base.service.ISupplierlinkerService;
import com.ejianc.business.base.vo.*;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.base.service.ISupplierinfoService;

/**
 * 供应商基本信息
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("supplierinfo")
public class SupplierinfoController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "supply-info";//此处需要根据实际修改

    @Autowired
    private ISupplierinfoService service;
    @Autowired
    private ISupplierlinkerService supplierlinkerService;
    @Autowired
    private ISupplierbankService supplierbankService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<SupplierinfoVO> saveOrUpdate(@RequestBody SupplierinfoVO saveOrUpdateVO) {
    	SupplierinfoEntity entity = BeanMapper.map(saveOrUpdateVO, SupplierinfoEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
//                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        QueryWrapper query=new QueryWrapper();
        query.eq("supply_name",entity.getSupplyName());
        query.eq("org_id",entity.getOrgId());
        List<SupplierinfoEntity> list = service.list(query);
        if (list.size()>0){
            for (int i = 0; i < list.size(); i++) {
                SupplierinfoEntity Entity = list.get(i);
                if (!String.valueOf(Entity.getId()).equals(String.valueOf(entity.getId()))){
//                    System.out.println(saveId == editId);
                    throw new BusinessException("供应商名称已存在，请修改供应商名称后保存");
                }
            }
        }
    	service.saveOrUpdate(entity, false);
    	SupplierinfoVO vo = BeanMapper.map(entity, SupplierinfoVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<SupplierinfoVO> queryDetail(Long id) {
    	SupplierinfoEntity entity = service.selectById(id);
    	SupplierinfoVO vo = BeanMapper.map(entity, SupplierinfoVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<SupplierinfoVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (SupplierinfoVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /*CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(SupplierinfoVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<SupplierinfoVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("supplyName");
        fuzzyFields.add("categoryName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<SupplierinfoEntity> page = service.queryPage(param,false);
        IPage<SupplierinfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), SupplierinfoVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<SupplierinfoEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Supplierinfo-export.xlsx", beans, response);
    }

    /**
     * @Description:参照
     * @param pageNumber
     * @param pageSize
     * @param condition
     * @param searchObject
     * @param searchText
     * @return void
     */
    @RequestMapping(value = "/refSupplierinfoData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<SupplierinfoVO>> refSupplierinfoData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("supplyName");
        fuzzyFields.add("categoryName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
            String orgId = _con.getString("orgId");
            if (orgId!=null) {
                param.getParams().put("org_id", new Parameter(QueryParam.EQ, orgId));
            }
        }

        IPage<SupplierinfoEntity> page = service.queryPage(param,false);
        IPage<SupplierinfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), SupplierinfoVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    /***
     * @Description 查询供应商联系人列表
     * @param requestVO
     * @return
     */
    @PostMapping(value = "queryDetailBySupplyId")
    @ResponseBody
    public CommonResponse<IPage<SupplierlinkerVO>> queryDetailBySupplyId(@RequestBody RequestVO requestVO) {
        QueryParam queryParam = new QueryParam();
        queryParam.setPageSize(requestVO.getPageSize());
        queryParam.setPageIndex(requestVO.getPageIndex());
        queryParam.setOrderMap(requestVO.getOrderMap());
        queryParam.getParams().put("manage_id",new Parameter(QueryParam.EQ,requestVO.getId()));
        IPage<SupplierlinkerEntity> page = supplierlinkerService.queryPage(queryParam, false);
        IPage<SupplierlinkerVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), SupplierlinkerVO.class));
        return CommonResponse.success("查询详情成功！", pageData);
    }
    /***
     * @Description 查询供应商银行列表
     * @param requestVO
     * @return
     */
    @PostMapping(value = "queryBankBySupplyId")
    @ResponseBody
    public CommonResponse<IPage<SupplierbankVO>> queryBankBySupplyId(@RequestBody RequestVO requestVO) {
        QueryParam queryParam = new QueryParam();
        queryParam.setPageSize(requestVO.getPageSize());
        queryParam.setPageIndex(requestVO.getPageIndex());
        queryParam.setOrderMap(requestVO.getOrderMap());
        queryParam.getParams().put("manage_id",new Parameter(QueryParam.EQ,requestVO.getId()));
        IPage<SupplierbankEntity> page = supplierbankService.queryPage(queryParam, false);
        IPage<SupplierbankVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), SupplierbankVO.class));
        return CommonResponse.success("查询详情成功！", pageData);
    }
}

==> ejc-lz-impl-3.0.0-20220526.021003-106-sources.jar: com/ejianc/business/base/controller/SupplierinfoController.java <==
package com.ejianc.business.base.controller;

import java.io.Serializable;

import com.alibaba.fastjson.JSONArray;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.base.bean.*;
import com.ejianc.business.base.service.ISupplierbankService;
import com.ejianc.business.base.service.ISupplierlinkerService;
import com.ejianc.business.base.vo.*;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import com.ejianc.framework.skeleton.refer.util.ReferObjectUtil;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.base.service.ISupplierinfoService;

/**
 * 供应商基本信息
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("supplierinfo")
public class SupplierinfoController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "supply-info";//此处需要根据实际修改
    private static final String LINKER_BILL_CODE = "supply-lnker";//此处需要根据实际修改
    private static final String BANK_BILL_CODE = "supply-bank";//此处需要根据实际修改

    @Autowired
    private ISupplierinfoService service;
    @Autowired
    private ISupplierlinkerService supplierlinkerService;
    @Autowired
    private ISupplierbankService supplierbankService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<SupplierinfoVO> saveOrUpdate(@RequestBody SupplierinfoVO saveOrUpdateVO) {
    	SupplierinfoEntity entity = BeanMapper.map(saveOrUpdateVO, SupplierinfoEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
//                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        QueryWrapper query=new QueryWrapper();
        query.eq("supply_name",entity.getSupplyName());
        query.eq("org_id",entity.getOrgId());
        List<SupplierinfoEntity> list = service.list(query);
        if (list.size()>0){
            for (int i = 0; i < list.size(); i++) {
                SupplierinfoEntity Entity = list.get(i);
                if (!String.valueOf(Entity.getId()).equals(String.valueOf(entity.getId()))){
//                    System.out.println(saveId == editId);
                    throw new BusinessException("供应商名称已存在，请修改供应商名称后保存");
                }
            }
        }
    	service.saveOrUpdate(entity, false);
    	SupplierinfoVO vo = BeanMapper.map(entity, SupplierinfoVO.class);
        if (saveOrUpdateVO.getId()==null){
            // 新增时插入客户联系人
            SupplierlinkerEntity supplierlinkerEntity = new SupplierlinkerEntity();
            supplierlinkerEntity.setSupplyName(vo.getSupplyName());
            supplierlinkerEntity.setManageId(vo.getId());
            supplierlinkerEntity.setSupplyLinker(vo.getLinkerName());
            supplierlinkerEntity.setSupplyMobile(vo.getLinkerPhone());
            supplierlinkerEntity.setOrgId(vo.getOrgId());
            supplierlinkerEntity.setOrgName(vo.getOrgName());
            SupplierlinkerVO map = BeanMapper.map(supplierlinkerEntity, SupplierlinkerVO.class);
            BillCodeParam billCodeParam = BillCodeParam.build(LINKER_BILL_CODE,InvocationInfoProxy.getTenantid(),map);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                supplierlinkerEntity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
            }else{
                throw new BusinessException("网络异常， 客户联系人编码生成失败， 请稍后再试");
            }
            // 新增时插入客户银行
            supplierlinkerService.saveOrUpdate(supplierlinkerEntity,false);
            SupplierbankEntity supplierbankEntity = new SupplierbankEntity();
            supplierbankEntity.setSupplyName(vo.getSupplyName());
            supplierbankEntity.setManageId(vo.getId());
            supplierbankEntity.setSupplyBank(vo.getBankName());
            supplierbankEntity.setSupplyAccount(vo.getBankAccount());
            supplierbankEntity.setOrgId(vo.getOrgId());
            supplierbankEntity.setOrgName(vo.getOrgName());
            SupplierbankVO map1 = BeanMapper.map(supplierbankEntity, SupplierbankVO.class);
            BillCodeParam billCodeParam1 = BillCodeParam.build(BANK_BILL_CODE,InvocationInfoProxy.getTenantid(),map1);
            CommonResponse<String> billCode1 = billCodeApi.generateBillCode(billCodeParam1);
            if(billCode.isSuccess()) {
                supplierbankEntity.setCode(billCode1.getData());//此处需要根据实际修改 删除本行或者下一行
            }else{
                throw new BusinessException("网络异常， 客户银行编码生成失败， 请稍后再试");
            }
            supplierbankService.saveOrUpdate(supplierbankEntity,false);
        }
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<SupplierinfoVO> queryDetail(Long id) {
    	SupplierinfoEntity entity = service.selectById(id);
    	SupplierinfoVO vo = BeanMapper.map(entity, SupplierinfoVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<SupplierinfoVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (SupplierinfoVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /*CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(SupplierinfoVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<SupplierinfoVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("supplyName");
        fuzzyFields.add("categoryName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<SupplierinfoEntity> page = service.queryPage(param,false);
        IPage<SupplierinfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), SupplierinfoVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<SupplierinfoEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Supplierinfo-export.xlsx", beans, response);
    }

    /**
     * @Description:参照
     * @param pageNumber
     * @param pageSize
     * @param condition
     * @param searchObject
     * @param searchText
     * @return void
     */
    @RequestMapping(value = "/refSupplierinfoData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<SupplierinfoVO>> refSupplierinfoData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("supplyName");
        fuzzyFields.add("categoryName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
            String orgId = _con.getString("orgId");
            if (orgId!=null) {
                param.getParams().put("org_id", new Parameter(QueryParam.EQ, orgId));
            }
        }

        IPage<SupplierinfoEntity> page = service.queryPage(param,false);
        IPage<SupplierinfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        List<SupplierinfoVO> supplierinfoVOS = BeanMapper.mapList(pageData.getRecords(), SupplierinfoVO.class);
        if (!supplierinfoVOS.isEmpty()){
            supplierinfoVOS.forEach(e->{
                try {
                    JSONArray equcode = ReferObjectUtil.getReferEntityValue(e.getCategoryId().toString(), "SuppliercategoryRef");
                    if(!equcode.isEmpty()){
                        e.setCleanFare(StringUtils.isNotBlank(((JSONObject)equcode.get(0)).getString("cleanFare"))?new BigDecimal(((JSONObject)equcode.get(0)).getString("cleanFare")):null);
                    }
                } catch (Exception exception) {
                    exception.printStackTrace();
                }
            });
        }
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), SupplierinfoVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    /***
     * @Description 查询供应商联系人列表
     * @param requestVO
     * @return
     */
    @PostMapping(value = "queryDetailBySupplyId")
    @ResponseBody
    public CommonResponse<IPage<SupplierlinkerVO>> queryDetailBySupplyId(@RequestBody RequestVO requestVO) {
        QueryParam queryParam = new QueryParam();
        queryParam.setPageSize(requestVO.getPageSize());
        queryParam.setPageIndex(requestVO.getPageIndex());
        queryParam.setOrderMap(requestVO.getOrderMap());
        queryParam.getParams().put("manage_id",new Parameter(QueryParam.EQ,requestVO.getId()));
        IPage<SupplierlinkerEntity> page = supplierlinkerService.queryPage(queryParam, false);
        IPage<SupplierlinkerVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), SupplierlinkerVO.class));
        return CommonResponse.success("查询详情成功！", pageData);
    }
    /***
     * @Description 查询供应商银行列表
     * @param requestVO
     * @return
     */
    @PostMapping(value = "queryBankBySupplyId")
    @ResponseBody
    public CommonResponse<IPage<SupplierbankVO>> queryBankBySupplyId(@RequestBody RequestVO requestVO) {
        QueryParam queryParam = new QueryParam();
        queryParam.setPageSize(requestVO.getPageSize());
        queryParam.setPageIndex(requestVO.getPageIndex());
        queryParam.setOrderMap(requestVO.getOrderMap());
        queryParam.getParams().put("manage_id",new Parameter(QueryParam.EQ,requestVO.getId()));
        IPage<SupplierbankEntity> page = supplierbankService.queryPage(queryParam, false);
        IPage<SupplierbankVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), SupplierbankVO.class));
        return CommonResponse.success("查询详情成功！", pageData);
    }
}
